@@ -1,19 +1,8 @@
 import argparse
-import os
-import glob
 import sys
 from tablib import formats
 
-from irco import parser, tabular
-
-
-def get_file_list(sources):
-    for source in sources:
-        if os.path.isdir(source):
-            for path in glob.glob(os.path.join(source, '*.txt')):
-                yield path
-        elif os.path.isfile(source):
-            yield source
+from irco import utils
 
 
 def get_format(args, choices):
@@ -38,15 +27,6 @@ def get_format(args, choices):
     return format
 
 
-def get_dataset(source, records=None):
-    table = tabular.Table(notset=None)
-    for path in get_file_list(source):
-        with open(path) as fh:
-            for record in parser.parse(fh, records):
-                table.add(record)
-    return table.dataset()
-
-
 def write(fh, dataset, format):
     fh.write(getattr(dataset, format))
 
@@ -66,7 +46,7 @@ def main():
     else:
         records = None
     format = get_format(args, format_choices)
-    dataset = get_dataset(args.source, records)
+    dataset = utils.get_dataset(args.source, records)
 
     if args.output == '-':
         write(sys.stdout, dataset, format)
