@@ -1,6 +1,7 @@
 import argparse
 from sqlalchemy import create_engine
 from irco import models
+from irco.logging import sentry
 
 
 def main():
@@ -10,5 +11,10 @@ def main():
 
     args = argparser.parse_args()
 
+    sentry.context.merge({
+        'tags': {'command': 'irco-init'},
+        'extra': {'parsed_arguments': args.__dict__}
+    })
+
     engine = create_engine(args.database, echo=args.verbose)
     models.Base.metadata.create_all(engine)
